.. :changelog:

History
-------

0.4.0 (2020-05-20)
++++++++++++++++++

* Migrated to Channels 2
* Added support for Django 2.2 / 3.0
* Dropped support for Python 2
* Dropped support for Django < 2.2

0.3.3 (2018-01-01)
++++++++++++++++++

* Fixed support for newer channel versions
* Fixed error in signal handling
* Added support for Django 1.11
* Improved test coverage

0.3.2 (2016-12-02)
++++++++++++++++++

* Add support for Django 1.10

0.3.1 (2016-09-10)
++++++++++++++++++

* Fix error in js message'

0.3.0 (2016-08-03)
++++++++++++++++++

* Make easier to customize the knocker url

0.2.0 (2016-06-11)
++++++++++++++++++

* Fixed documentation
* Improved routing setting in tests

0.1.1 (2016-04-08)
++++++++++++++++++

* Add Add pause_knocks / active_knocks functions.

0.1.0 (2016-04-07)
++++++++++++++++++

* First release on PyPI.
